@@ -1,29 +1,15 @@
-/*  This file is part of the KDE libraries
- *  Copyright 2008  David Faure  <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #ifndef KMIMEASSOCIATIONS_H
 #define KMIMEASSOCIATIONS_H
 
-#include <QSet>
-#include <QStringList>
 #include <QHash>
+#include <QSet>
 #include <kserviceoffer.h>
 class KConfigGroup;
 class KServiceFactory;
@@ -37,14 +23,16 @@ struct ServiceTypeOffersData {
 class KOfferHash
 {
 public:
-    KOfferHash() {}
+    KOfferHash()
+    {
+    }
     KOfferHash(const KOfferHash &) = delete;
-    KOfferHash& operator=(const KOfferHash &) = delete;
+    KOfferHash &operator=(const KOfferHash &) = delete;
     QList<KServiceOffer> offersFor(const QString &serviceType) const
     {
-        QHash<QString, ServiceTypeOffersData>::const_iterator it = m_serviceTypeData.find(serviceType);
-        if (it != m_serviceTypeData.end()) {
-            return (*it).offers;
+        auto it = m_serviceTypeData.constFind(serviceType);
+        if (it != m_serviceTypeData.cend()) {
+            return it.value().offers;
         }
         return QList<KServiceOffer>();
     }
@@ -52,28 +40,37 @@ public:
     void removeServiceOffer(const QString &serviceType, const KService::Ptr &service);
     bool hasRemovedOffer(const QString &serviceType, const KService::Ptr &service) const;
 
-    const QHash<QString, ServiceTypeOffersData> &serviceTypeData() const { return m_serviceTypeData; }
+    const QHash<QString, ServiceTypeOffersData> &serviceTypeData() const
+    {
+        return m_serviceTypeData;
+    }
 
 private:
     QHash<QString, ServiceTypeOffersData> m_serviceTypeData;
 };
 
-/**
+/*!
  * Parse mimeapps.list files and:
- * - modify mimetype associations in the relevant services (using KServiceFactory)
+ * - modify MIME type associations in the relevant services (using KServiceFactory)
  * - remember preference order specified by user
+ *
+ * \internal
  */
 class KMimeAssociations
 {
 public:
     explicit KMimeAssociations(KOfferHash &offerHash, KServiceFactory *serviceFactory);
 
+    static QStringList mimeAppsFiles();
+
     // Read mimeapps.list files
     void parseAllMimeAppsList();
 
     void parseMimeAppsList(const QString &file, int basePreference);
 
 private:
+    static QStringList mimeAppsDirs();
+
     void parseAddedAssociations(const KConfigGroup &group, const QString &file, int basePreference);
     void parseRemovedAssociations(const KConfigGroup &group, const QString &file);
 
